# Generated by roxygen2: do not edit by hand

S3method(print,av1r_options)
export(av1r_options)
export(av1r_status)
export(convert_folder)
export(convert_to_av1)
export(detect_backend)
export(measure_ssim)
export(read_tiff_stack)
export(vulkan_available)
export(vulkan_devices)
useDynLib(AV1R, .registration = TRUE)
